==> maptools-0.2.1.tar.gz: maptools-0.2.1/README.md <==
# maptools
> Python library for manipulating EM maps

[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Language grade: Python](https://img.shields.io/lgtm/grade/python/g/jmp1985/maptools.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/jmp1985/maptools/context:python)
[![Total alerts](https://img.shields.io/lgtm/alerts/g/jmp1985/maptools.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/jmp1985/maptools/alerts/)

## Installation

To install from the github repository do the following

```sh
python -m pip install git+https://github.com/rosalindfranklininstitute/maptools.git@master
```

To install from source, clone this repository. Then do the following:

```sh
python -m pip install .
```

If you would like to run the tests then, clone this repository and then do the following:

```sh
python -m pip install .[test]
```

## Installation for developers

To install for development, clone this repository and then do the following:

```sh
python -m pip install -e .
```

## Testing

To run the tests, follow the installation instructions for developers and then do the following:

```sh
pytest
```

## Issues

Please use the [GitHub issue tracker](https://github.com/rosalindfranklininstitute/maptools/issues) to submit bugs or request features.

## License

Copyright Diamond Light Source and Rosalind Franklin Institute, 2021

Distributed under the terms of the GPLv3 license, maptools is free and open source software.

==> maptools-0.3.3.tar.gz: maptools-0.3.3/README.md <==
# maptools
> Python library for manipulating EM maps

[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Language grade: Python](https://img.shields.io/lgtm/grade/python/g/jmp1985/maptools.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/jmp1985/maptools/context:python)
[![Total alerts](https://img.shields.io/lgtm/alerts/g/jmp1985/maptools.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/jmp1985/maptools/alerts/)
[![Building](https://github.com/rosalindfranklininstitute/maptools/actions/workflows/python-package.yml/badge.svg)](https://github.com/rosalindfranklininstitute/maptools/actions/workflows/python-package.yml)
[![Publishing](https://github.com/rosalindfranklininstitute/maptools/actions/workflows/python-publish.yml/badge.svg)](https://github.com/rosalindfranklininstitute/maptools/actions/workflows/python-publish.yml)
[![DOI](https://zenodo.org/badge/361779782.svg)](https://zenodo.org/badge/latestdoi/361779782)

## Installation

To install from the github repository do the following

```sh
python -m pip install git+https://github.com/rosalindfranklininstitute/maptools.git@master
```

To install from source, clone this repository. Then do the following:

```sh
python -m pip install .
```

If you would like to run the tests then, clone this repository and then do the following:

```sh
python -m pip install .[test]
```

## Installation for developers

To install for development, clone this repository and then do the following:

```sh
python -m pip install -e .
```

## Testing

To run the tests, follow the installation instructions for developers and then do the following:

```sh
pytest
```

## Issues

Please use the [GitHub issue tracker](https://github.com/rosalindfranklininstitute/maptools/issues) to submit bugs or request features.

## License

Copyright Diamond Light Source and Rosalind Franklin Institute, 2021

Distributed under the terms of the GPLv3 license, maptools is free and open source software.
